%aat.cls
%
% Based on the original LaTeX article.sty.
%
% This is LaTeX2e class support for submissions authors manuscripts to journal 
% 'Acta Astrophysica Taurica'
%
% Latest version of this file can be found on the web page of journal 
% 'Acta Astrophysica Taurica' at https://astrophysicatauricum.org
% 
% This package may be distributed and/or modified under the conditions of the 
% LaTeX Project Public License, either version 1.3 of this license or any later 
% version. The latest version of this license is in
%    http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX version 
% 2005/12/01 or later.
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{aat}[2019/10/01 version 1.0]
\@twocolumntrue
\def\ds@twocolumn{\@twocolumntrue}
\def\ds@onecolumn{\@twocolumnfalse}
\message
 {^^J=====================================================================
  ^^J aat.cls version 1.0 (2019/10/01) LaTeX2e paper class for journal 
  ^^J 'Acta Astrophysica Taurica' 
  ^^J=====================================================================^^J^^J}
  
% Necessary packages
\RequirePackage{cmap}
\RequirePackage[T1]{fontenc}
\RequirePackage{ae,aecompl}
\RequirePackage[utf8]{inputenc}
\RequirePackage{substitutefont}
%\RequirePackage[english]{babel}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{newtxtext}
\RequirePackage{newtxmath}


\RequirePackageWithOptions{graphicx,epsf}
\graphicspath{{figures/}}

\RequirePackage{booktabs}
\RequirePackage{url}
\RequirePackage{ifthen}
 
\RequirePackage{soulutf8}
\sodef\so{}{.05em}{.5em plus.5em}{.1em plus.05em minus.05em}

\RequirePackage[dvipsnames]{xcolor}
\definecolor{dodgerblue}{RGB}{30,144,255}
\definecolor{colorh}{RGB}{0,20,20}

\RequirePackage[a4paper]{geometry}
\special {papersize=210mm,297mm}

\newcommand{\thepage}{{\small\arabic{page}}}
\PassOptionsToPackage{hyphens}{url}
\RequirePackage{hyperref}
\RequirePackage{breakurl}


%Hyperlinks
\hypersetup{colorlinks=true,linkcolor={dodgerblue},citecolor={dodgerblue},filecolor={dodgerblue},urlcolor={dodgerblue}}
\urlstyle{same}

% usenatbib option
\newif\if@usenatbib
\def\ds@usenatbib{\@usenatbibtrue}

\newif\if@press
\def\ds@press{\@presstrue}

% landscape option
%
\newif\ifSFB@landscape
\def\ds@landscape{\SFB@landscapetrue}

% referee option
%
\newif\ifSFB@referee
\def\ds@referee{%
 \SFB@refereetrue
 \@twocolumnfalse
}
\newif\ifdoublesp@cing
\def\ds@doublespacing{%
 \doublesp@cingtrue
}%

\newcommand{\printdoi}{}
\newcommand{\thedoi}{}
\renewcommand{\printdoi}[1]{%
    \renewcommand{\thedoi}{\mbox{#1}}
}
% Prevent fleqn throwing an 'unknown option' warning
\newif\if@fleqn
\def\ds@fleqn{\@fleqntrue}

\ExecuteOptions{a4paper,twoside,twocolumn,final,runningheads,fleqn}
\ProcessOptions\relax

\frenchspacing
\def~{\penalty\@M\kern3pt}
%%%
\def\Aat@shortname{Acta\,Astrophys.\,Tau.}~%
\def\Aat@fullname{\so{Acta\,\,Astrophysica\,\,Taurica}}
\def\Aat@fname{\sl{ACTA\,ASTROPHYSICA\,TAURICA}}

%\def\Aat@udc{UDK}
\def\Aat@homepage{\href{https://astrophysicatauricum.org}{www.astrophysicatauricum.org}}

%\def\captions{%
\def\prefacename   {Preface}
\def\refname       {References}
\def\abstractname  {Abstract}
\def\bibname       {References}
\def\chaptername   {Chapter}
\def\appendixname  {Appendix}
%
%FOR BOOKS 
\def\contentsname  {Content}
%
%FOR ARTICLES, ETC.
%\def\contentsname  {Content}
\def\listfigurename{List of figures}
\def\listtablename {List of tables}
\def\indexname     {Index}
\def\partname      {Part}


%  ****************************************
%  *              Font sizes              *
%  ****************************************
%  

%\newif\if@envcountreset\@envcountresetfalse
%\def\ds@envcountreset{\@envcountresettrue}
 
\def\@mbi{cmmib10}
\def\@ptsize{0} \@namedef{ds@11pt}{\def\@ptsize{1}}
\@namedef{ds@12pt}{\def\@ptsize{2}}
\def\ds@twoside{\@twosidetrue \@mparswitchtrue}
\def\ds@draft{\overfullrule
5pt}
\@options
 
\ds@twoside

\lineskip 1pt
\normallineskip 1pt
\ifSFB@referee
  \def\baselinestretch{1.5}
\else
  \ifdoublesp@cing
  \def\baselinestretch{2}
\else
  \def\baselinestretch{1}
\fi\fi

%\lineskip 1pt \normallineskip 1pt
%\renewcommand\baselinestretch{1}
%
\if@twocolumn
  \renewcommand\normalsize{\@setfontsize\normalsize\@xpt{11}%
   \abovedisplayskip 6pt plus 2pt minus 2pt
   \belowdisplayskip \abovedisplayskip
   \abovedisplayshortskip 6pt plus 2pt
   \belowdisplayshortskip \abovedisplayshortskip
   \let\@listi\@listI}
 \else
 \ifSFB@referee
  \renewcommand\normalsize{\@setfontsize\normalsize\@xiipt{12}%
   \abovedisplayskip 4pt plus 1pt minus 1pt
   \belowdisplayskip \abovedisplayskip
   \abovedisplayshortskip 4pt plus 1pt
   \belowdisplayshortskip \abovedisplayshortskip
   \let\@listi\@listI}
 \else
\renewcommand\normalsize{\@setfontsize\normalsize\@xpt{12}
\abovedisplayskip=3 mm plus6pt minus 4pt
\belowdisplayskip=3 mm plus6pt minus 4pt
\abovedisplayshortskip=0mm plus6pt minus 2pt
\belowdisplayshortskip=2 mm plus4pt minus 4pt}
\fi
\fi
\newcommand\small{\@setfontsize\small\@ixpt{11}
\abovedisplayskip=2.5 mm plus5pt minus 3pt
\belowdisplayskip=2.5 mm plus5pt minus 3pt
\abovedisplayshortskip=0mm plus6pt minus 2pt
\belowdisplayshortskip=2 mm plus4pt minus 4pt
\renewcommand\@listi{\topsep 4pt plus 2pt minus 2pt}}
%
\newcommand\footnotesize{\@setfontsize\footnotesize\@ixpt{11}
\abovedisplayskip=2.5 mm plus5pt minus 3pt
\belowdisplayskip=2.5 mm plus5pt minus 3pt
\abovedisplayshortskip=0mm plus6pt minus 2pt
\belowdisplayshortskip=2 mm plus4pt minus 4pt
\renewcommand\@listi{\topsep 4pt plus 2pt minus 2pt}}
%
\newcommand\scriptsize{\@setfontsize\scriptsize\@viipt{8.4}}
\newcommand\tiny{\@setfontsize\tiny\@vpt{6}}
\newcommand\large{\@setfontsize\large\@xipt{13.2}}
\newcommand\Large{\@setfontsize\Large\@xiipt{14.4}}
\newcommand\LARGE{\@setfontsize\LARGE\@xivpt{20}}
\newcommand\huge{\@setfontsize\huge\@xxpt{24}}
\newcommand\Huge{\@setfontsize\Huge\@xxvpt{30}}
%
\normalsize

%%%%%%%%%%%%%%%%%%%%%%%% Extra Math / Symbol code %%%%%%%%%%%%%%%%%%%%%%%%

\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\DeclareOldFontCommand{\sl}{\normalfont\slshape}{\@nomath\sl}
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\@nomath\sc}
\DeclareRobustCommand\cal{\@fontswitch{\relax}{\mathcal}}
\DeclareRobustCommand\mit{\@fontswitch{\relax}{\mathchoice}}
\DeclareRobustCommand*\cal{\@fontswitch{\relax}{\mathcal}}
\DeclareRobustCommand*\mit{\@fontswitch{\relax}{\mathchoice}}

\newcommand\la{\mathrel{\mathchoice {\vcenter{\offinterlineskip\halign{\hfil
$\displaystyle##$\hfil\cr<\cr\sim\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\textstyle##$\hfil\cr
<\cr\sim\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptstyle##$\hfil\cr
<\cr\sim\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptscriptstyle##$\hfil\cr
<\cr\sim\cr}}}}}

\newcommand\ga{\mathrel{\mathchoice {\vcenter{\offinterlineskip\halign{\hfil
$\displaystyle##$\hfil\cr>\cr\sim\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\textstyle##$\hfil\cr
>\cr\sim\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptstyle##$\hfil\cr
>\cr\sim\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptscriptstyle##$\hfil\cr
>\cr\sim\cr}}}}}

\newcommand\sun{\hbox{$\odot$}}
\newcommand\degr{\hbox{$^\circ$}}
\newcommand\arcmin{\hbox{$^\prime$}}
\newcommand\arcsec{\hbox{$^{\prime\prime}$}}
\newcommand\utw{\smash{\rlap{\lower5pt\hbox{$\sim$}}}}
\newcommand\udtw{\smash{\rlap{\lower6pt\hbox{$\approx$}}}}
\newcommand\fd{\hbox{$.\!\!^{\rm d}$}}
\newcommand\fh{\hbox{$.\!\!^{\rm h}$}}
\newcommand\fm{\hbox{$.\!\!^{\rm m}$}}
\newcommand\fs{\hbox{$.\!\!^{\rm s}$}}
\newcommand\fdg{\hbox{$.\!\!^\circ$}}
\newcommand\epst{\hbox{$\varepsilon\!\!\!\!^{\toch}$}}
\newcommand\farcm{\hbox{$.\mkern-4mu^\prime$}}
\newcommand\farcs{\hbox{$.\!\!^{\prime\prime}$}}
\newcommand\fp{\hbox{$.\!\!^{\scriptscriptstyle\rm p}$}}
\newcommand\cor{\mathrel{\mathchoice {\hbox{$\widehat=$}}{\hbox{$\widehat=$}}
{\hbox{$\scriptstyle\hat=$}}
{\hbox{$\scriptscriptstyle\hat=$}}}}

\newcommand\sol{\mathrel{\mathchoice {\vcenter{\offinterlineskip\halign{\hfil
$\displaystyle##$\hfil\cr\sim\cr<\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\textstyle##$\hfil\cr\sim\cr
<\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptstyle##$\hfil\cr\sim\cr
<\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptscriptstyle##$\hfil\cr
\sim\cr<\cr}}}}}

\newcommand\sog{\mathrel{\mathchoice {\vcenter{\offinterlineskip\halign{\hfil
$\displaystyle##$\hfil\cr\sim\cr>\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\textstyle##$\hfil\cr\sim\cr
>\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptstyle##$\hfil\cr
\sim\cr>\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptscriptstyle##$\hfil\cr
\sim\cr>\cr}}}}}

\newcommand\lse{\mathrel{\mathchoice {\vcenter{\offinterlineskip\halign{\hfil
$\displaystyle##$\hfil\cr<\cr\simeq\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\textstyle##$\hfil\cr
<\cr\simeq\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptstyle##$\hfil\cr
<\cr\simeq\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptscriptstyle##$\hfil\cr
<\cr\simeq\cr}}}}}

\newcommand\gse{\mathrel{\mathchoice {\vcenter{\offinterlineskip\halign{\hfil
$\displaystyle##$\hfil\cr>\cr\simeq\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\textstyle##$\hfil\cr
>\cr\simeq\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptstyle##$\hfil\cr
>\cr\simeq\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptscriptstyle##$\hfil\cr
>\cr\simeq\cr}}}}}

\newcommand\grole{\mathrel{\mathchoice {\vcenter{\offinterlineskip\halign{\hfil
$\displaystyle##$\hfil\cr>\cr\noalign{\vskip-1.5pt}<\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\textstyle##$\hfil\cr
>\cr\noalign{\vskip-1.5pt}<\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptstyle##$\hfil\cr
>\cr\noalign{\vskip-1pt}<\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptscriptstyle##$\hfil\cr
>\cr\noalign{\vskip-0.5pt}<\cr}}}}}

\newcommand\leogr{\mathrel{\mathchoice {\vcenter{\offinterlineskip\halign{\hfil
$\displaystyle##$\hfil\cr<\cr\noalign{\vskip-1.5pt}>\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\textstyle##$\hfil\cr
<\cr\noalign{\vskip-1.5pt}>\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptstyle##$\hfil\cr
<\cr\noalign{\vskip-1pt}>\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptscriptstyle##$\hfil\cr
<\cr\noalign{\vskip-0.5pt}>\cr}}}}}

\newcommand\loa{\mathrel{\mathchoice {\vcenter{\offinterlineskip\halign{\hfil
$\displaystyle##$\hfil\cr<\cr\approx\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\textstyle##$\hfil\cr
<\cr\approx\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptstyle##$\hfil\cr
<\cr\approx\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptscriptstyle##$\hfil\cr
<\cr\approx\cr}}}}}

\newcommand\goa{\mathrel{\mathchoice {\vcenter{\offinterlineskip\halign{\hfil
$\displaystyle##$\hfil\cr>\cr\approx\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\textstyle##$\hfil\cr
>\cr\approx\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptstyle##$\hfil\cr
>\cr\approx\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptscriptstyle##$\hfil\cr
>\cr\approx\cr}}}}}

\newcommand\diameter{{\ifmmode\mathchoice
{\ooalign{\hfil\hbox{$\displaystyle/$}\hfil\crcr
{\hbox{$\displaystyle\mathchar"20D$}}}}
{\ooalign{\hfil\hbox{$\textstyle/$}\hfil\crcr
{\hbox{$\textstyle\mathchar"20D$}}}}
{\ooalign{\hfil\hbox{$\scriptstyle/$}\hfil\crcr
{\hbox{$\scriptstyle\mathchar"20D$}}}}
{\ooalign{\hfil\hbox{$\scriptscriptstyle/$}\hfil\crcr
{\hbox{$\scriptscriptstyle\mathchar"20D$}}}}
\else{\ooalign{\hfil/\hfil\crcr\mathhexbox20D}}%
\fi}}

\newcommand\getsto{\mathrel{\mathchoice {\vcenter{\offinterlineskip
\halign{\hfil
$\displaystyle##$\hfil\cr\gets\cr\to\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\textstyle##$\hfil\cr\gets
\cr\to\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptstyle##$\hfil\cr\gets
\cr\to\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptscriptstyle##$\hfil\cr
\gets\cr\to\cr}}}}}

\newcommand\lid{\mathrel{\mathchoice {\vcenter{\offinterlineskip\halign{\hfil
$\displaystyle##$\hfil\cr<\cr\noalign{\vskip1.2pt}=\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\textstyle##$\hfil\cr<\cr
\noalign{\vskip1.2pt}=\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptstyle##$\hfil\cr<\cr
\noalign{\vskip1pt}=\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptscriptstyle##$\hfil\cr
<\cr
\noalign{\vskip0.9pt}=\cr}}}}}

\newcommand\gid{\mathrel{\mathchoice {\vcenter{\offinterlineskip\halign{\hfil
$\displaystyle##$\hfil\cr>\cr\noalign{\vskip1.2pt}=\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\textstyle##$\hfil\cr>\cr
\noalign{\vskip1.2pt}=\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptstyle##$\hfil\cr>\cr
\noalign{\vskip1pt}=\cr}}}
{\vcenter{\offinterlineskip\halign{\hfil$\scriptscriptstyle##$\hfil\cr
>\cr
\noalign{\vskip0.9pt}=\cr}}}}}

\newcommand\ts{\thinspace}

\newcommand\squareforqed{\hbox{\rlap{$\sqcap$}$\sqcup$}}
\newcommand\sq{\ifmmode\squareforqed\else{\unskip\nobreak\hfil
\penalty50\hskip1em\null\nobreak\hfil\squareforqed
\parfillskip=0pt\finalhyphendemerits=0\endgraf}\fi}

\def\vec#1{\mathchoice{\mbox{\boldmath$\displaystyle\bf#1$}}
{\mbox{\boldmath$\textstyle\bf#1$}}
{\mbox{\boldmath$\scriptstyle\bf#1$}}
{\mbox{\boldmath$\scriptscriptstyle\bf#1$}}}

%%%%%%%%%%%%%%%%%%%%% End of Extra Math / Symbol code %%%%%%%%%%%%%%%%%%%%%

%  ****************************************
%  *            Page layout               *
%  ****************************************
%

%Side margins
\if@twocolumn
  \setlength\oddsidemargin {-2.5pc}
  \setlength\evensidemargin {-2.5pc}
	\hoffset0.5pc % offsets
 \else
 \ifSFB@referee
  \setlength\oddsidemargin{\z@}
  \setlength\evensidemargin{\z@}
 \else
\setlength\oddsidemargin{-2pc}
  \setlength\evensidemargin{-2pc}
	\fi
\fi
%
\setlength\marginparwidth{4pc}
\setlength\marginparsep{0.5pc}

%Vertical spacing
\setlength\topmargin {\z@}
\setlength{\topskip}{9pt}
\setlength{\headheight}{14pt}
\setlength{\headsep}{15pt}
\setlength{\footskip}{22pt}
%
% DIMENSION OF TEXT: % SFB 0.1.01
%
\newdimen\SFB@measure
\SFB@measure 42pc
%
\setlength\textheight{682pt}
\setlength\textwidth{\SFB@measure}
%
\ifSFB@landscape
 \setlength\textwidth{\textheight}
 \setlength\textheight{\SFB@measure}
\fi
\ifSFB@referee
 \setlength\textwidth{39pc}
\fi
\setlength\columnsep{2pc}
\setlength\columnseprule{0pt}

%Footnotes
\setlength\footnotesep{6pt}
\setlength\skip{\footins 19.5pt plus 12pt minus 1pt}

%Floats
\setlength\floatsep{ 12pt plus 5.5pt minus 1pt}
\setlength\textfloatsep{ 12pt plus 7.5pt}
\setlength\intextsep{ 12pt plus 5.5pt minus 2pt}
\setlength\dblfloatsep {12pt plus 2pt minus 2pt}
\setlength\dbltextfloatsep {20pt plus 2pt minus 4pt}
\setlength\@fptop {0pt plus 1fil} 
\setlength\@fpsep {8pt plus 2fil} 
\setlength\@fpbot {0pt plus 1fil}
\setlength\@dblfptop {0pt plus1fil} 
\setlength\@dblfpsep {8pt plus2fil}
\setlength\@dblfpbot {0pt plus1fil}
\setlength\marginparpush {5pt}


%  ****************************************
%  *           Paragraphing               *
%  ****************************************
%
\setlength\parskip {0pt plus 1pt} 
\setlength\parindent {1.5em} 
\setlength\topsep {8pt plus 2pt minus 4pt}
\partopsep 2pt plus 1pt minus 1pt \itemsep \z@
\@lowpenalty 51 
\@medpenalty 151 
\@highpenalty 301
\@beginparpenalty-\@lowpenalty
\@endparpenalty -\@lowpenalty
\@itempenalty-\@lowpenalty
\clubpenalty=0 \widowpenalty=10000

%  ****************************************
%  *       PARTS, SECTIONS               *
%  ****************************************
%
\newcounter{part}
\newcounter {section}
\newcounter {subsection}[section]
\newcounter {subsubsection}[subsection]
\newcounter {paragraph}[subsubsection]
\newcounter {subparagraph}[paragraph]
\renewcommand\thepart{\Roman{part}}
\def\thesection {\arabic{section}}
\def\thesubsection    {\thesection.\arabic{subsection}}
\def\thesubsubsection {\thesubsection.\arabic{subsubsection}}
\def\theparagraph     {\thesubsubsection.\arabic{paragraph}}
\def\thesubparagraph  {\theparagraph.\arabic{subparagraph}}

% Parts
%
\def\part{\par \addvspace{4ex} \@afterindentfalse
 \secdef\@part\@spart}
\def\@part[#1]#2{\ifnum \c@secnumdepth >\m@ne 
  \refstepcounter{part}
  \addcontentsline{toc}{part}{\thepart \hspace{1em}#1}
 \else
  \addcontentsline{toc}{part}{#1}
 \fi 
  {\parindent 0pt \raggedright
   \ifnum \c@secnumdepth >\m@ne \Large \bf
    Part\thepart\par\nobreak\fi\huge
   \bf #2\markboth{}{}\par} \nobreak \vskip 3ex \@afterheading }
  \def\@spart#1{{\parindent 0pt \raggedright
   \huge \bf
 #1\par} \nobreak \vskip 3ex \@afterheading }

% Sections
%
\def\@sect#1#2#3#4#5#6[#7]#8{\ifnum #2>\c@secnumdepth
  \def\@svsec{}\else
  \refstepcounter{#1}\edef\@svsec{\csname the#1\endcsname\enspace }\fi
  \@tempskipa #5\relax
   \ifdim \@tempskipa>\z@
  \begingroup #6\relax
  \noindent{\hskip #3\relax\@svsec}{\interlinepenalty \@M #8\par}
  \endgroup
    \csname #1mark\endcsname{#7}\addcontentsline
   {toc}{#1}{\ifnum #2>\c@secnumdepth \else
            \protect\numberline{\csname the#1\endcsname}\fi
          #7}\else
  \def\@svsechd{#6\hskip #3\@svsec #8\csname #1mark\endcsname
            {#7}\addcontentsline
             {toc}{#1}{\ifnum #2>\c@secnumdepth \else
               \protect\numberline{\csname the#1\endcsname}\fi
             #7}}\fi
  \@xsect{#5}}

\def\section{\@startsection {section}{1}{\z@}{-18pt plus -4pt minus
-4pt}{12pt plus 4pt minus 4pt}{\Large\bf\boldmath
\pretolerance=10000\relax\rightskip=0pt plus8em}}
%
\def\subsection{\@startsection{subsection}{2}{\z@}{-18pt plus-4pt minus
 -4pt}{8pt plus 4pt minus 4pt}{\normalsize\bf\boldmath
\pretolerance=10000\relax\rightskip=0pt plus8em}}
%
\def\subsubsection{\@startsection{subsubsection}{3}{\z@}{-18pt plus -4pt minus
-4pt}{12pt plus 4pt minus 4pt}{\normalsize\bf\boldmath
 \pretolerance=10000\relax\rightskip=0pt plus8em}}
 %
\def\paragraph{\@startsection{paragraph}{4}{\z@}{-12pt plus -4pt minus
 -4pt}{-0.5em plus -.22em minus -0.1em}{\normalsize\it}}
 %
\def\subparagraph#1{\typeout{You should not use
\protect\subparagraph \space in this style.}\vskip0.5cm
You should not use $\backslash${\tt subparagraph} in this
style.\vskip0.5cm}

\setcounter{secnumdepth}{4}

\def\appendix{\par
 \@addtoreset{equation}{section}
 \@addtoreset{table}{section}
 \@addtoreset{figure}{section}
 \setcounter{section}{0}
 \setcounter{subsection}{0}
 \setcounter{subsubsection}{0}
 \setcounter{equation}{0}
 \setcounter{figure}{0}
 \setcounter{table}{0}
 \def\thesection{\Alph{section}}
 \renewcommand\thesubsection{\thesection\arabic{subsection}}
 \renewcommand\theequation{\thesection\arabic{equation}}
  \renewcommand\thefigure{\thesection\@arabic\c@figure}
  \renewcommand\thetable{\thesection\@arabic\c@table}
  \renewcommand{\theHsection}{A\arabic{section}} % for hyperref links
}

% Define acknowledgements
\def\acknowledgementname{\bf Acknowledgements. }
\def\acknowledgements{\vspace{12pt}\noindent{\acknowledgementname}%
\ignorespaces}


%  ****************************************
%  *                Lists                 *
%  ****************************************
%
\leftmargini 17pt     \leftmarginii 17pt
\leftmarginiii 17pt   \leftmarginiv 17pt
\leftmarginv 10pt       \leftmarginvi 10pt
\leftmargin\leftmargini \labelwidth\leftmargini
\setlength\labelsep {0.5em}
\labelwidth\leftmargini\advance\labelwidth-\labelsep
\parsep 0pt plus 1pt
%
\def\@listI{\leftmargin\leftmargini
 \parsep \z@
 \topsep 6pt plus 1pt minus 1pt
 \itemsep \z@ plus .1pt
}
\let\@listi\@listI
\@listi
\def\@listii{\leftmargin\leftmarginii
 \topsep 6pt plus 1pt minus 1pt
 \parsep \z@
 \itemsep \z@ plus .1pt
}
%\def\@listi{\leftmargin\leftmargini}
\def\@listii{\leftmargin\leftmarginii
 \labelwidth\leftmarginii\advance\labelwidth-\labelsep
 \topsep 0pt plus 1pt}
\def\@listiii{\leftmargin\leftmarginiii
 \labelwidth\leftmarginiii\advance\labelwidth-\labelsep
 \topsep 0pt plus 1pt}
\def\@listiv{\leftmargin\leftmarginiv
 \labelwidth\leftmarginiv\advance\labelwidth-\labelsep
 \topsep 0pt plus 1pt}
\def\@listv{\leftmargin\leftmarginv
 \labelwidth\leftmarginv\advance\labelwidth-\labelsep
 \topsep 0pt plus 1pt}
\def\@listvi{\leftmargin\leftmarginvi
 \labelwidth\leftmarginvi\advance\labelwidth-\labelsep
 \topsep 0pt plus 1pt}
%
% ENUMERATE
%
\newcommand\labelenumi{\arabic{enumi}.}
\renewcommand\theenumi{\arabic{enumi}}
\newcommand\labelenumii{(\alph{enumii})}
\renewcommand\theenumii{\alph{enumii}}
\renewcommand\p@enumii{\theenumi}
\newcommand\labelenumiii{\roman{enumiii}.}
\renewcommand\theenumiii{\roman{enumiii}}
\renewcommand\p@enumiii{\theenumi(\theenumii)}
\newcommand\labelenumiv{\Alph{enumiv}.}
\renewcommand\theenumiv{\Alph{enumiv}}
\renewcommand\p@enumiv{\p@enumiii\theenumiii}
%
\def\labelitemi{\bf --}
\def\labelitemii{$\bullet$}
\def\labelitemiii{$\ast$}
\def\labelitemiv{$\cdot$}
%
% DESCRIPTION
%
\def\descriptionlabel#1{\hspace\labelsep \bf #1}
\def\description{\list{}{\labelwidth\z@ \itemindent-\leftmargin
 \let\makelabel\descriptionlabel}}
\let\enddescription\endlist

%  ****************************************
%  *            Environments              *
%  ****************************************
%
% VERSE
\def\verse{\let\\=\@centercr
 \list{}{\itemsep\z@ \itemindent -1.5em\listparindent \itemindent
 \rightmargin\leftmargin\advance\leftmargin 1.5em}\item[]}
\let\endverse\endlist
%
% QUOTATION
\def\quotation{\list{}{\listparindent 1.5em
 \itemindent\listparindent
 \rightmargin\leftmargin}\item[]}
\let\endquotation=\endlist
%
% QUOTE
\def\quote{\list{}{\rightmargin\leftmargin}\item[]}
\let\endquote=\endlist
%
% EQUATION
%\def\theequation{\arabic{equation}}
%
% TITLEPAGE
\def\titlepage{\@restonecolfalse\if@twocolumn\@restonecoltrue\onecolumn
 \else \newpage \fi \thispagestyle{empty}\c@page\z@}
\def\endtitlepage{\if@restonecol\twocolumn \else \newpage \fi}
%
% ARRAY AND TABULAR
\arraycolsep   5pt
\tabcolsep     6pt
\arrayrulewidth .5pt
\doublerulesep 1.5pt
\tabbingsep \labelsep
%
% MINIPAGE
\skip\@mpfootins = \skip\footins
%
% FRAMEBOX
\fboxsep = 3pt 
\fboxrule = .4pt

%  ****************************************
%  *         Title and Abstract           *
%  ****************************************
%
\def\titlerunning#1{\gdef\@titlerunning{#1}}
\def\@titlerunning{}
%
\def\authorrunning#1{\gdef\@authorrunning{#1}}
\def\@authorrunning{}
%
\def\email#1{{e-mail: \tt#1}}
%
\def\maketitle{\par
 \begingroup
 \parindent=\z@
 \def\thefootnote{\fnsymbol{footnote}}
 \if@twocolumn
 \twocolumn[\@maketitle]
 \else \newpage
 \global\@topnum\z@ \@maketitle 
 \fi
  \thispagestyle{empty} \@thanks
 \endgroup
 \let\maketitle\relax
 \let\@maketitle\relax
 \setcounter{footnote}{0}
 \gdef\@author{}\gdef\@title{}\gdef\@subtitle{}%
 \let\thanks\relax}
%
\newcounter{@inst}
\newcounter{@auth}
\newdimen\instindent
%
\def\institute#1{\gdef\@institute{#1}}
\def\institutename{\par
 \begingroup
 \parskip=0pt
 \setcounter{@inst}{1}%
 \def\and{\par\stepcounter{@inst}%
 \hangindent\instindent\hangafter=0\noindent
 \llap{$^{\the@inst}$\enspace}\ignorespaces}%
 \setbox0=\vbox{\def\thanks##1{}\@institute}%
 \ifnum\c@@inst>9\relax\setbox0=\hbox{$^{88}$\enspace}%
                 \else\setbox0=\hbox{$^{8}$\enspace}\fi
 \instindent=\wd0\relax
 \ifnum\c@@inst=1\relax\else
 \setcounter{footnote}{\c@@inst}%
 \setcounter{@inst}{1}%
 \hangindent\instindent\hangafter=0\noindent
 \llap{$^{\the@inst}$\enspace}\fi\ignorespaces
 \@institute\par
 \endgroup}

%   
\def\inst#1{\unskip\/$^{#1}$}
\def\subtitle#1{\gdef\@subtitle{#1}}
\def\@subtitle{}
% 
\def\@maketitle{\newpage
 \vbox to0pt{}\vskip-8mm
 \maketitulline\par
 \makeheadbox\par
  \if@press\vskip5.5mm\else\vskip13.5mm\fi
 {\LARGE \center \bf\boldmath
  \pretolerance=10000
   \@title \par}\vskip .4cm
\if!\@subtitle!\else {\Large \center\bf\boldmath
  \vskip -.45cm
  \pretolerance=10000
  \@subtitle \par}\fi
{\Large \center\rm{\lineskip .5em %
\@author\vskip.40cm}%
\def\inst##1{}\def\thanks##1{}\def\and{}%
\setcounter{@auth}{1}%
\if!\@titlerunning!\else\def\@title{\@titlerunning}\fi
\if!\@authorrunning!\else\def\@author{\@authorrunning}\fi
\xdef\@author{\@author\unskip\unskip}%
\xdef\@title{\ignorespaces\@title}%
\instindent=\hsize\advance\instindent by-1cm\relax
\setbox0=\hbox{\@author}\ifdim\wd0>\instindent
\typeout{The running head produced by the
\protect\author \space command}\typeout{exceeds the pagewidth,
please supply a short form with \protect\authorrunning.}%
\def\@author{Authors suppressed due to excessive length,
please use {\tt$\backslash$authorrunning}.}\fi
\setbox0=\hbox{\@title}\ifdim\wd0>\instindent
\typeout{The running head produced by the
\protect\title \space command}\typeout{exceeds the pagewidth,
please supply a short form with \protect\titlerunning.}%
\def\@title{Title suppressed due to excessive length,
please use {\tt$\backslash$titlerunning}.}\fi
\markboth{\@author}{\@title}}%
 {\small\rm\institutename
  \vskip .5cm {\normalsize\noindent\@date\vskip .5cm}}
 \par
 }
%
\def\abstract{\if@twocolumn
   \start@SFBbox\@abstract
 \else
   \@abstract
 \fi}
\def\endabstract{\if@twocolumn
   \endquotation\finish@SFBbox
 \else
  \endquotation
 \fi}
\def\@abstract{%
    \begin{center}%
		{\reset@font\normalsize{\bf ABSTRACT}\\\reset@font\large}%
    \end{center}%
    \quotation\noindent
} 
%
\def\keywordname{\bf Key words: }
\def\keywords{\par\vspace{6pt}\noindent{\keywordname}}
%
\def\today{\ifcase\month\or
 January\or February\or March\or April\or May\or June\or
 July\or August\or September\or October\or November\or December\fi
 \space\number\day, \number\year}

\def\start@SFBbox{\@next\@currbox\@freelist{}{}%
 \global\setbox\@currbox
 \vbox\bgroup
  \hsize \textwidth
  \@parboxrestore
}
\def\finish@SFBbox{\par\vskip -\parskip
  \egroup
  \global\count\@currbox\tw@
  \global\@dbltopnum\@ne
  \global\@dbltoproom\maxdimen\@addtodblcol
  \global\vsize\@colht
  \global\@colroom\@colht
}

%Titul page
\newcommand{\horrulet}{\rule{\linewidth}{0.3pt}}
\newcommand{\horruleb}{\color{darkgray}\rule{\linewidth}{3pt}} 

\if@press
\input{header/header.sty}
	\else
	\def\maketitulline{%
     \vbox{\noindent
	 \ignorespaces
		 {\begin{minipage}[c]{17.4cm}
		 {{\Aat@fname}\vskip0.1cm\hrule\vskip0.1cm
		 \noindent\ignorespaces
		 \bf{\Aat@shortname\,\@nametom\hfill}}
		 \end{minipage}
		}
	}}
	\def\nametom#1{\gdef\@nametom{#1}}
	\def\@nametom{}
	\def\makeheadbox{}
\fi

\ifSFB@referee
	\def\maketitulline{%
     \fbox{\noindent
	 \ignorespaces
		{\begin{minipage}[c]{37pc}
		 {{\Aat@fname\par}
		 \noindent\ignorespaces
		 \small{\@nametom\hfill}}
		 \end{minipage}
	   }
	}}
	\def\nametom#1{\gdef\@nametom{#1}}
	\def\@nametom{}
	\def\makeheadbox{}
\fi
%
%  ****************************************
%  *         Table of Contents            *
%  ****************************************
%
\def\@pnumwidth{1.55em}
\def\@tocrmarg {2.55em}
\def\@dotsep{4.5}
\setcounter{tocdepth}{3}
\def\contentsname{\bf Contents}
\def\tableofcontents{\section*{\bf Content}
 \@starttoc{toc}}
\def\l@part#1#2{\addpenalty{\@secpenalty}
 \addvspace{2.25em plus 1pt} \begingroup
 \@tempdima 3em \parindent \z@ \rightskip \@pnumwidth \parfillskip
-\@pnumwidth
 {\Large \bf \leavevmode #1\hfil \hbox to\@pnumwidth{\hss #2}}\par
 \nobreak \endgroup}
%
\def\numberline#1{\advance\hangindent by\@tempdima
\hbox to\@tempdima{\hss#1\enspace}}
%
\def\bf@dottedtocline#1#2#3#4#5{\ifnum #1>\c@tocdepth
 \else
  \vskip \z@ plus .2pt
  {\leftskip #2\relax \rightskip \@tocrmarg \parfillskip -\rightskip
    \parindent #2\relax\@afterindenttrue
   \interlinepenalty\@M
   \leavevmode
   \@tempdima #3\relax \advance\leftskip \@tempdima \hbox{}\hskip
   -\leftskip
{\bf#4}\nobreak\leaders\hbox{$\m@th \mkern \@dotsep mu.\mkern \@dotsep
       mu$}\hfill \nobreak \hbox to\@pnumwidth{\hfil\rm #5}\par}\fi}
%
\def\l@section{\vskip2mm\bf@dottedtocline{1}{0em}{1.7em}}
\def\l@subsection{\@dottedtocline{2}{1.7em}{2.3em}}
\def\l@subsubsection{\@dottedtocline{3}{4em}{2em}}
\def\l@paragraph{\@dottedtocline{4}{6em}{2em}}
\def\l@subparagraph{\@dottedtocline{5}{8em}{2em}}
\def\listfigurename{\bf List of Figures}% List of Figures
\def\listoffigures{\section*{\lisfigurename\markboth
 {\lisfigurename}{\lisfigurename}}\@starttoc{lof}}
\def\l@figure{\@dottedtocline{1}{1.5em}{2.3em}}
\def\listtablename{\bf List of Tables}% List of Tables
\def\listoftables{\section*{\listtablename\markboth
 {\listtablename}{\listtablename}}\@starttoc{lot}}
\let\l@table\l@figure

%  ****************************************
%  *             Bibliography             *
%  ****************************************
%
% References
%

\renewcommand\refname{\bf References}
\def\thebibliography#1{\section*{References}
\list {}{%
	 \setlength\labelwidth{1.4em}\leftmargin\labelwidth
	 \setlength\parsep{0pt}\setlength\itemsep{0pt}
	 \setlength{\itemindent}{-\leftmargin}
	 \usecounter{enumi}}
	 \def\newblock{\hskip .11em plus .33em minus -.07em}
	 \sloppy
	 \sfcode`\.=1000\relax}
\def\endthebibliography{\endlist\normalsize} 


% Redefine \@cite so no square brackets are output.
% Redefine \@biblabel so the label is not output in the bibliography.
\def\@cite#1#2{{#1\if@tempswa , #2\fi}}
\def\@biblabel#1{}

\if@usenatbib%
	\def\newblock{\hskip .11em plus .33em minus -.07em}
	\usepackage[authoryear]{natbib}
	\bibpunct{(}{)}{;}{a}{,}{,~}
	\renewcommand\refname{\bf References}
\fi

%  ****************************************
%  *             UDC, DOI, etc.           *
%  ****************************************
%\udc
%\newcommand{\udc}{}
%\renewcommand{\udc}[1]{{\small\rm\Aat@udc~#1}}

\def\@urlcharsother{%
  \let\do\@makeother 
  \do\\\do\$\do\&\do\#\do\^\do\_\do\%\do\~}

%\doi
\def\doi{\begingroup
  \@urlcharsother
  \@ifnextchar[%
    {\@doi}
    {\@doi[]}}
\def\@doi[#1]#2{%
  \def\@tempa{#1}%
  \ifx\@tempa\@empty
    \href{http://dx.doi.org/#2}{doi:#2}%
  \else
    \href{http://dx.doi.org/#2}{#1}%
  \fi
  \endgroup
  }
  
  
%\eprint
\def\eprint#1#2{%
  \@eprint#1:#2::\@nil}
\def\@eprint@arXiv#1{\href{http://arxiv.org/abs/#1}{{arXiv:#1}}}
\def\@eprint@dblp#1{\href{http://dblp.uni-trier.de/rec/bibtex/#1.xml}{dblp:#1}}
\def\@eprint#1:#2:#3:#4\@nil{%
  \def\@tempa{#1}%
  \def\@tempb{#2}%
  \def\@tempc{#3}%
  \ifx\@tempc\@empty
    \let\@tempc\@tempb
    \let\@tempb\@tempa
  \fi
  \ifx\@tempb\@empty
    % default to arXiv
    \def\@tempb{arXiv}%
  \fi
  %
  \@ifundefined{@eprint@\@tempb}
    {\@tempb:\@tempc}
    % or call macro '@eprint@\@tempb' on the argument \@tempc
    {\expandafter\expandafter\csname @eprint@\@tempb\endcsname\expandafter{\@tempc}}%
  }

%  ****************************************
%  *              The Index               *
%  ****************************************
%
\newif\if@restonecol
\def\theindex{\section*{INDEX}
 \addcontentsline{toc}{section}{INDEX}
 \reset@font\footnotesize \parindent\z@ \parskip\z@ plus .1pt\relax
 \let\item\@idxitem}
\def\@idxitem{\par\hangindent 1em}
\def\subitem {\par\hangindent 1em \hspace*{1em}}
\def\subsubitem{\par\hangindent 1em\hspace*{1em}}
\def\endtheindex{\if@restonecol\onecolumn\else\clearpage\fi}
\def\indexspace{\par\vskip\baselineskip \relax}

%  ****************************************
%  *             Footnotes                *
%  ****************************************
%
\def\footnoterule{\kern-3\p@\hrule width 2 true cm\kern 2.6\p@}
 
\renewcommand{\thefootnote}{\mbox{{$^\arabic{footnote}$}}}
\renewcommand{\thempfootnote}{\mbox{{${\alph{mpfootnote}}$}}}

%
\def\@thanks{}
\def\@fnsymbol#1{\ifcase#1\or \mbox{${^{\star}}$}\or 
\mbox{${^{\star\star}}$}\or \mbox{${^{\star\star\star}}$}\or \mbox{${^{\star\star\star\star}}$}%
   \or \dagger\or \ddagger\or  \mathchar "278\or \mathchar "27B\or \|\or **\or \dagger\dagger
   \or \ddagger\ddagger\else\@ctrerr\fi\relax}

\providecommand\@makefntext[1]{}

\renewcommand{\@makefnmark}{$\@thefnmark$}
\renewcommand\@makefntext[1]{\parindent 1em\noindent
  ${\@thefnmark}$\hspace{2pt}#1}

\newcommand{\fixfootnotes}{%
\renewcommand{\@makefnmark}{$^{\@thefnmark}$}%
\renewcommand\@makefntext[1]{\parindent 1em\noindent%
  $^{\@thefnmark}$\hspace{2pt}##1}%
\renewcommand{\thefootnote}{\arabic{footnote}}%
%\setcounter{footnote}{0}%
}
  
  
%	****************************************
%	*         Figures and Tables           *
%	****************************************
%
%TABLES
\newcounter{table}
\def\tablename{Table}
\renewcommand\thetable{\@arabic\c@table}
\def\fps@table{tbp}
\def\ftype@table{2}
\def\ext@table{lot}
\def\fnum@table{\tablename\nobreakspace\thetable.}
\newenvironment{table}
               {\@float{table}}
               {\end@float}
\newenvironment{table*}
               {\@dblfloat{table}}
               {\end@dblfloat}
\newlength\abovecaptionskip
\newlength\belowcaptionskip
\setlength\abovecaptionskip{10\p@}
\setlength\belowcaptionskip{0\p@}
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
 \sbox\@tempboxa{\small\textbf{#1.} #2}% 
  \ifdim \wd\@tempboxa >\hsize
   {\@caption@left@right@skip\small\textbf{#1.} #2\par} 
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}

\long\def\@makecaption#1#2{\vskip 10pt
 \setbox\@tempboxa\hbox{\small{\bf #1} #2}
 \ifdim \wd\@tempboxa >\hsize \unhbox\@tempboxa\par \else
 \hbox to\hsize{\hfil\box\@tempboxa\hfil}
 \fi\vskip 5pt}

\long\def\@caption#1[#2]#3{\addcontentsline{\csname
  ext@#1\endcsname}{#1}{\protect\numberline{\csname
  the#1\endcsname}{\ignorespaces #2}}\par
  \begingroup
    \@parboxrestore
    \@makecaption{\csname fnum@#1\endcsname}{\ignorespaces #3}\par
  \endgroup}
  
%FIGURES
\newcounter{figure}
\def\figurename{Fig.}
\renewcommand \thefigure {\@arabic\c@figure}
\def\fps@figure{tbp}
\def\ftype@figure{1}
\def\ext@figure{lof}
\def\fnum@figure{Fig.\nobreakspace\thefigure.}
\newenvironment{figure}
               {\@float{figure}}
               {\end@float}
\newenvironment{figure*}
               {\@dblfloat{figure}}
               {\end@dblfloat}
  

\long\def\SFB@makefigurecaption#1#2{\vskip 6pt
  \setbox\@tempboxa\hbox{\reset@font\small{\bf #1}%
    \if@cont \ -- {\it continued}\else{\bf .}\fi\ {\rm #2}\par}%
 \ifdim \wd\@tempboxa >\hsize
   {\reset@font\small{\bf #1}%
     \if@cont \ -- {\it continued}\else{\bf .}\fi\ {\rm #2}\par}%
 \else
   \ifst@rredfloat
     \hbox to\hsize{\hfill\box\@tempboxa\hfill}%
   \else
     \hbox to\hsize{\hfill\box\@tempboxa\hfill}%
   \fi
 \fi
 \vskip 6pt
 \@contfalse
}

\long\def\SFB@maketablecaption#1#2{\vskip 6pt
  \sbox\@tempboxa\hbox{\reset@font\small{\bf #1}%
    \if@cont \ -- {\it continued}\else{\bf .}\fi\ {\rm #2}\par}%
 \ifdim \wd\@tempboxa >\hsize
    {\reset@font\small{\bf #1}%
    \if@cont \ -- {\it continued}\else{\bf .}\fi\ {\rm #2}\par}%
 \else
   \hbox to\hsize{\box\@tempboxa\hfill}%
 \fi
 \vskip 6pt
 \@contfalse
}

\newif\if@cont
\def\caption{\refstepcounter\@captype \@dblarg{\@caption\@captype}}
\def\contcaption{\@conttrue\SFB@caption\@captype}

\long\def\SFB@caption#1#2{%\par
 \begingroup
  \@parboxrestore
  \reset@font\normalsize
  \@makecaption{\csname fnum@#1\endcsname}{\ignorespaces #2}\par
 \endgroup}
 %Headings
\mark{{}{}}

\def\ps@headings{\let\@mkboth\markboth
\def\@oddfoot{}
\def\@evenfoot{}%
\def\@evenhead{\small\rm\thepage\hfil\@authorrunning}
\def\@oddhead{\hbox{}\small\rm\@titlerunning\hfil\thepage}
\def\sectionmark##1{\markboth{##1}{}}
 \def\subsectionmark##1{\markright{##1}}}

\def\ps@myheadings{\let\@mkboth\@gobbletwo
\def\@oddhead{\hbox{}\sl\rightmark \hfil \rm\thepage}
\def\@oddfoot{}
\def\@evenhead{\rm \thepage\hfil\sl \leftmark\hbox{}}
\def\@evenfoot{}
\def\sectionmark##1{}
\def\subsectionmark##1{}
}
\clubpenalty=10000 \widowpenalty=10000 
\ps@headings \pagenumbering{arabic} %\onecolumn
\if@twoside\else\raggedbottom\fi 


%JOURNAL ABBREVIATIONS
\def\ApJ           {Astrophys. J.}
\def\ApJS          {Astrophys. J. Suppl. Ser.}
\def\ApL           {Astrophys. Lett.}
\def\ApSSS         {Astrophys. Space Sci.}
\def\MNRAS         {Mon. Not. Roy. Astron. Soc.}
\def\PASP          {Publ. Astron. Soc. Pacific.}
\def\AAp           {Astron. Astrophys.}
\def\AARv          {Astron. Astrophys. Rev.}
\def\AAS           {Astron. Astrophys. Suppl. Ser.}
\def\AAT           {Astron. Astrophys. Trans.}
\def\AJ            {Astron. J.}
\def\AcA           {Acta Astron.}
\def\ARAA          {Ann. Rev. Astron. Astrophys.}
\def\AstL          {Astron. Lett.}
\def\AN            {Astron. Nachr.}
\def\ARep          {Astron. Rep.}
\def\AT            {Astron. Tsirk.}


\if@twoside
\else
  \raggedbottom
\fi
\if@twocolumn
  \twocolumn
  \sloppy
  \flushbottom
\else
  \onecolumn
\fi
\endinput


%% end of aat.cls 